@@ -1,5 +1,6 @@
 """Base index classes."""
 import json
+import logging
 from abc import abstractmethod
 from typing import (
     Any,
@@ -22,7 +23,8 @@ from gpt_index.indices.node_utils import get_nodes_from_document
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.query_runner import QueryRunner
-from gpt_index.indices.query.schema import QueryConfig, QueryMode
+from gpt_index.indices.query.query_transform import BaseQueryTransform
+from gpt_index.indices.query.schema import QueryBundle, QueryConfig, QueryMode
 from gpt_index.indices.registry import IndexRegistry
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
@@ -49,8 +51,6 @@ class BaseGPTIndex(Generic[IS]):
             will use the default PromptHelper.
         chunk_size_limit (Optional[int]): Optional chunk size limit. If not provided,
             will use the default chunk size limit (4096 max input size).
-        verbose (bool): Optional bool. If True, will print out additional information
-            during the index building process.
         include_extra_info (bool): Optional bool. If True, extra info (i.e. metadata)
             of each Document will be prepended to its text to help with queries.
             Default is True.
@@ -69,7 +69,6 @@ class BaseGPTIndex(Generic[IS]):
         index_registry: Optional[IndexRegistry] = None,
         prompt_helper: Optional[PromptHelper] = None,
         chunk_size_limit: Optional[int] = None,
-        verbose: bool = False,
         include_extra_info: bool = True,
     ) -> None:
         """Initialize with parameters."""
@@ -105,9 +104,7 @@ class BaseGPTIndex(Generic[IS]):
             )
             self._validate_documents(documents)
             # TODO: introduce document store outside __init__ function
-            self._index_struct = self.build_index_from_documents(
-                documents, verbose=verbose
-            )
+            self._index_struct = self.build_index_from_documents(documents)
         # update index registry and docstore with index_struct
         self._update_index_registry_and_docstore()
 
@@ -144,7 +141,12 @@ class BaseGPTIndex(Generic[IS]):
         self._index_registry.type_to_query[cur_type] = self.get_query_map()
 
         # update docstore with current struct
-        self._docstore.add_documents([self.index_struct])
+        # NOTE: we call allow_update=True: in old versions of the docstore,
+        # the index_struct was not stored in the docstore. whereas
+        # in the new docstore, index_struct is stored in the docstore.
+        # if we want to break BW compatibility, we can just remove this line
+        # and only insert into docstore during index construction.
+        self._docstore.add_documents([self.index_struct], allow_update=True)
 
     def _process_documents(
         self,
@@ -171,10 +173,8 @@ class BaseGPTIndex(Generic[IS]):
                         f"Invalid doc ID: {sub_index_struct.get_doc_id()}"
                     )
                 results.append(sub_index_struct)
-            elif isinstance(doc, (Document, IndexStruct)):
+            elif isinstance(doc, Document):
                 results.append(doc)
-                # update docstore
-                docstore.add_documents([doc])
             else:
                 raise ValueError(f"Invalid document type: {type(doc)}.")
         return cast(List[BaseDocument], results)
@@ -238,7 +238,7 @@ class BaseGPTIndex(Generic[IS]):
         self._index_struct.doc_id = doc_id
         # Note: we also need to delete old doc_id, and update docstore
         self._docstore.delete_document(old_doc_id)
-        self._docstore.add_documents([self._index_struct])
+        self._docstore.add_documents([self._index_struct], allow_update=True)
 
     def get_doc_id(self) -> str:
         """Get doc_id for index struct.
@@ -264,17 +264,13 @@ class BaseGPTIndex(Generic[IS]):
         )
 
     @abstractmethod
-    def _build_index_from_documents(
-        self, documents: Sequence[BaseDocument], verbose: bool = False
-    ) -> IS:
+    def _build_index_from_documents(self, documents: Sequence[BaseDocument]) -> IS:
         """Build the index from documents."""
 
     @llm_token_counter("build_index_from_documents")
-    def build_index_from_documents(
-        self, documents: Sequence[BaseDocument], verbose: bool = False
-    ) -> IS:
+    def build_index_from_documents(self, documents: Sequence[BaseDocument]) -> IS:
         """Build the index from documents."""
-        return self._build_index_from_documents(documents, verbose=verbose)
+        return self._build_index_from_documents(documents)
 
     @abstractmethod
     def _insert(self, document: BaseDocument, **insert_kwargs: Any) -> None:
@@ -305,17 +301,9 @@ class BaseGPTIndex(Generic[IS]):
 
         Args:
             doc_id (str): document id
-            full_delete (bool): whether to delete the document from the docstore.
-                By default this is True.
-            verbose (bool): whether to print verbose output. By default this is False.
 
         """
-        verbose = delete_kwargs.pop("verbose", False)
-        full_delete = delete_kwargs.pop("full_delete", True)
-        if verbose:
-            print(f"> Deleting document: {doc_id}")
-        if full_delete:
-            self._docstore.delete_document(doc_id)
+        logging.debug(f"> Deleting document: {doc_id}")
         self._delete(doc_id, **delete_kwargs)
 
     def update(self, document: DOCUMENTS_INPUT, **update_kwargs: Any) -> None:
@@ -345,9 +333,10 @@ class BaseGPTIndex(Generic[IS]):
 
     def query(
         self,
-        query_str: str,
-        verbose: bool = False,
+        query_str: Union[str, QueryBundle],
         mode: str = QueryMode.DEFAULT,
+        query_transform: Optional[BaseQueryTransform] = None,
+        use_async: bool = False,
         **query_kwargs: Any,
     ) -> Response:
         """Answer a query.
@@ -374,8 +363,9 @@ class BaseGPTIndex(Generic[IS]):
                 self._docstore,
                 self._index_registry,
                 query_configs=query_configs,
-                verbose=verbose,
+                query_transform=query_transform,
                 recursive=True,
+                use_async=use_async,
             )
             return query_runner.query(query_str, self._index_struct)
         else:
@@ -393,8 +383,9 @@ class BaseGPTIndex(Generic[IS]):
                 self._docstore,
                 self._index_registry,
                 query_configs=[query_config],
-                verbose=verbose,
+                query_transform=query_transform,
                 recursive=False,
+                use_async=use_async,
             )
             return query_runner.query(query_str, self._index_struct)
 
@@ -424,12 +415,21 @@ class BaseGPTIndex(Generic[IS]):
 
         """
         result_dict = json.loads(index_string)
-        index_struct = cls.index_struct_cls.from_dict(result_dict["index_struct"])
-        type_to_struct = {index_struct.get_type(): type(index_struct)}
+        if "index_struct" in result_dict:
+            index_struct = cls.index_struct_cls.from_dict(result_dict["index_struct"])
+            index_struct_id = index_struct.get_doc_id()
+        elif "index_struct_id" in result_dict:
+            index_struct_id = result_dict["index_struct_id"]
+        else:
+            raise ValueError("index_struct or index_struct_id must be provided.")
+
+        type_to_struct = {cls.index_struct_cls.get_type(): cls.index_struct_cls}
         docstore = DocumentStore.load_from_dict(
             result_dict["docstore"],
             type_to_struct=type_to_struct,
         )
+        if "index_struct_id" in result_dict:
+            index_struct = docstore.get_document(index_struct_id)
         return cls(index_struct=index_struct, docstore=docstore, **kwargs)
 
     @classmethod
@@ -477,8 +477,8 @@ class BaseGPTIndex(Generic[IS]):
                 "other indices. Please define a `ComposableGraph` and use "
                 "`save_to_string` and `load_from_string` on that instead."
             )
-        out_dict: Dict[str, dict] = {
-            "index_struct": self.index_struct.to_dict(),
+        out_dict: Dict[str, Any] = {
+            "index_struct_id": self.index_struct.get_doc_id(),
             "docstore": self.docstore.serialize_to_dict(),
         }
         return json.dumps(out_dict, **save_kwargs)
