@@ -96,7 +96,7 @@ class BaseGPTKeywordTableIndex(BaseGPTIndex[KeywordTable]):
         """Extract keywords from text."""
 
     def _build_index_from_documents(
-        self, documents: Sequence[BaseDocument], verbose: bool = False
+        self, documents: Sequence[BaseDocument]
     ) -> KeywordTable:
         """Build the index from documents."""
         text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
