@@ -59,6 +59,7 @@ class GPTTreeIndex(BaseGPTIndex[IndexGraph]):
         num_children: int = 10,
         llm_predictor: Optional[LLMPredictor] = None,
         build_tree: bool = True,
+        use_async: bool = False,
         **kwargs: Any,
     ) -> None:
         """Initialize params."""
@@ -67,6 +68,7 @@ class GPTTreeIndex(BaseGPTIndex[IndexGraph]):
         self.summary_template = summary_template or DEFAULT_SUMMARY_PROMPT
         self.insert_prompt: TreeInsertPrompt = insert_prompt or DEFAULT_INSERT_PROMPT
         self.build_tree = build_tree
+        self._use_async = use_async
         super().__init__(
             documents=documents,
             index_struct=index_struct,
@@ -98,7 +100,7 @@ class GPTTreeIndex(BaseGPTIndex[IndexGraph]):
         self._validate_build_tree_required(mode)
 
     def _build_index_from_documents(
-        self, documents: Sequence[BaseDocument], verbose: bool = False
+        self, documents: Sequence[BaseDocument]
     ) -> IndexGraph:
         """Build the index from documents."""
         # do simple concatenation
@@ -107,9 +109,10 @@ class GPTTreeIndex(BaseGPTIndex[IndexGraph]):
             self.summary_template,
             self._llm_predictor,
             self._prompt_helper,
+            self._use_async,
         )
         index_graph = index_builder.build_from_text(
-            documents, build_tree=self.build_tree, verbose=verbose
+            documents, build_tree=self.build_tree
         )
         return index_graph
 
