@@ -15,8 +15,12 @@ from gpt_index.readers.faiss import FaissReader
 
 # readers
 from gpt_index.readers.file.base import SimpleDirectoryReader
+from gpt_index.readers.github_readers.github_repository_reader import (
+    GithubRepositoryReader,
+)
 from gpt_index.readers.google_readers.gdocs import GoogleDocsReader
 from gpt_index.readers.make_com.wrapper import MakeWrapper
+from gpt_index.readers.mbox import MboxReader
 from gpt_index.readers.mongo import SimpleMongoReader
 from gpt_index.readers.notion import NotionPageReader
 from gpt_index.readers.obsidian import ObsidianReader
@@ -58,4 +62,6 @@ __all__ = [
     "MakeWrapper",
     "TwitterTweetReader",
     "ObsidianReader",
+    "GithubRepositoryReader",
+    "MboxReader",
 ]
